==> zio-aws-devicefarm_3-5.17.112.1-sources.jar: zio/aws/devicefarm/model/StopJobResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class StopJobResponse(
    job: Option[zio.aws.devicefarm.model.Job] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.StopJobResponse = {
    import StopJobResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.StopJobResponse
      .builder()
      .optionallyWith(job.map(value => value.buildAwsValue()))(_.job)
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.StopJobResponse.ReadOnly =
    zio.aws.devicefarm.model.StopJobResponse.wrap(buildAwsValue())
}
object StopJobResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.StopJobResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.StopJobResponse =
      zio.aws.devicefarm.model
        .StopJobResponse(job.map(value => value.asEditable))
    def job: Option[zio.aws.devicefarm.model.Job.ReadOnly]
    def getJob: ZIO[Any, AwsError, zio.aws.devicefarm.model.Job.ReadOnly] =
      AwsError.unwrapOptionField("job", job)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.StopJobResponse
  ) extends zio.aws.devicefarm.model.StopJobResponse.ReadOnly {
    override val job: Option[zio.aws.devicefarm.model.Job.ReadOnly] = scala
      .Option(impl.job())
      .map(value => zio.aws.devicefarm.model.Job.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.StopJobResponse
  ): zio.aws.devicefarm.model.StopJobResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-devicefarm_3-6.20.74.2-sources.jar: zio/aws/devicefarm/model/StopJobResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class StopJobResponse(
    job: Optional[zio.aws.devicefarm.model.Job] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.StopJobResponse = {
    import StopJobResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.StopJobResponse
      .builder()
      .optionallyWith(job.map(value => value.buildAwsValue()))(_.job)
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.StopJobResponse.ReadOnly =
    zio.aws.devicefarm.model.StopJobResponse.wrap(buildAwsValue())
}
object StopJobResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.StopJobResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.StopJobResponse =
      zio.aws.devicefarm.model
        .StopJobResponse(job.map(value => value.asEditable))
    def job: Optional[zio.aws.devicefarm.model.Job.ReadOnly]
    def getJob: ZIO[Any, AwsError, zio.aws.devicefarm.model.Job.ReadOnly] =
      AwsError.unwrapOptionField("job", job)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.StopJobResponse
  ) extends zio.aws.devicefarm.model.StopJobResponse.ReadOnly {
    override val job: Optional[zio.aws.devicefarm.model.Job.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.job())
        .map(value => zio.aws.devicefarm.model.Job.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.StopJobResponse
  ): zio.aws.devicefarm.model.StopJobResponse.ReadOnly = new Wrapper(impl)
}
